require 'net/http'
require 'uri'
require 'json'

module MailCatcher
  module API
    module Client
      MESSAGE_ENDPOINT = '/messages/%{message_id}.json'.freeze
      MESSAGE_INDEX_ENDPOINT = '/messages'.freeze

      def self.fetch_message_index
        request(:get, MESSAGE_INDEX_ENDPOINT)
      end

      def self.fetch_message(id)
        request(:get, format(MESSAGE_ENDPOINT, message_id: id))
      end

      def self.delete_all
        request(:delete, MESSAGE_INDEX_ENDPOINT)
      end

      def self.delete_message(id)
        request(:delete, format(MESSAGE_ENDPOINT, message_id: id))
      end

      def self.request(method, path)
        request = case method
                  when :get; Net::HTTP::Get.new(path)
                  when :delete; Net::HTTP::Delete.new(path)
                  else raise NotImplementedError, "Don't know how to request #{method} method"
                  end
        response = http.request(request)
        JSON.load(response.body)
      end

      def self.http
        uri = URI(MailCatcher::API.config.server)
        Net::HTTP.new(uri.host, uri.port)
      end
    end
  end
end
