require 'mailcatcher/api/client'
require 'mailcatcher/api/mailbox/message'

module MailCatcher
  module API
    class Mailbox
      class MessageCollection
        include Enumerable

        def each
          collection.each do |msg|
            yield(msg)
          end
          nil
        end

        private

        def collection
          @collection ||= load_collection
        end

        def load_collection
          collection_index.map do |msg|
            Mailbox::Message.new(client.fetch_message(msg['id']))
          end
        end

        def collection_index
          @collection_index ||= load_collection_index.sort { |a, b| b['id'] <=> a['id'] }
        end

        def load_collection_index
          client.fetch_message_index
        end

        def client
          MailCatcher::API::Client
        end
      end
    end
  end
end
